@@ -2,11 +2,11 @@
  * examples/proccpuinfo.c - simple program to read /proc/cpuinfo and print out 
  *                          some information.
  *
- * Copyright (C) 2006  Thomas Cort <linuxgeek@gmail.com>
+ * Copyright (C) 2006, 2007, 2008 Thomas Cort <tom@tomcort.com>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -15,11 +15,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
+#include <stdio.h>
 #include "proccpuinfo.h"
 
 int main() {
